pub struct Service<T>where
T: Float,{
pub total: T,
pub price_insurance_ex: T,
pub fee: T,
pub insured_amount: T,
pub service: String,
pub transit_time: String,
pub pickup_dates: Vec<String>,
pub pickup_time: HashMap<String, String>,
}Expand description
A service provided by one of the companies listed by Transdirect. It is put in the products file because it is a product provided by external companies.
Fields
total: Tprice_insurance_ex: Tfee: Tinsured_amount: Tservice: Stringtransit_time: Stringpickup_dates: Vec<String>pickup_time: HashMap<String, String>Trait Implementations
Sourceimpl<'de, T> Deserialize<'de> for Service<T>where
T: Float + Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Service<T>where
T: Float + Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl<T> Eq for Service<T>
impl<T> StructuralPartialEq for Service<T>where
T: Float,